@@ -20,8 +20,6 @@ from torch.cuda import amp
 from torch.nn.parallel import DistributedDataParallel as DDP
 from torch.utils.tensorboard import SummaryWriter
 from tqdm import tqdm
-
-from picsellia.client import Client
 from .test import test  # import test.py to get mAP after each epoch
 from .models.experimental import attempt_load
 from .models.yolo import Model
@@ -384,13 +382,13 @@ def train(hyp, opt, device, tb_writer=None, wandb=None, pxl=None):
                     if tag in verified_tags:
                         try:
                             name = str(tag).replace('/', '_')
-                            pxl.log(name=name, type=LogType.LINE, data=float(x))
+                            pxl.log(name=name, type=LogType.LINE, data=[float(x)])
                         except Exception as e:
                             logger.info(str(e))
                             try:
                                 #name = tag.cpu()
                                 name = str(tag).replace('/', '_')
-                                pxl.log(name=name, type=LogType.LINE, data=float(x))
+                                pxl.log(name=name, type=LogType.LINE, data=[float(x)])
                             except Exception as e:
                                 print(e)
                                 print(tag, "can't be uploaded")
